@@ -17,10 +17,21 @@ def setdefault_name(source_file, config):
 
     ##|  FIX NAME
     # add the extension if it exists and isn't ".html"
-    if ext and ext != config.get('html_extension'):
+    if ext and ext != config['html_extension']:
         name += '_' + ext[1:]  # pluck off the "." in front
 
     # replace non-word, hyphens, and spaces characters with _
     name = re.sub(r'[\W -]', '_', name, re.UNICODE)
     config['name'] = name.encode('ascii')
     return config
+
+
+setdefault_name.defaults = {
+    'rename_extensions': {
+        '.j2': u'.html',
+        '.jinja2': u'.html',
+        '.jinja': u'.html',
+        '.md': u'.html',
+    },
+    'html_extension': '.html'
+}
