@@ -1,3 +1,4 @@
+import sys
 import os
 from shutil import copy2
 from strange_case.nodes import FileNode
@@ -11,6 +12,6 @@ class AssetNode(FileNode):
         if not os.path.exists(target_path) or not self['skip']:
             copy2(source_path, target_path)
         elif self['verbose']:
-            print "Skipping %s" % target_path
+            sys.stderr.write("Skipping %s\n" % target_path)
         self.files_tracked.append(source_path)
         self.files_written.append(target_path)
